package com.shopingCardSystem.Service;

import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.InjectMocks;
import java.util.stream.Stream;
import org.junit.jupiter.api.Test;
import java.util.stream.Collectors;
import static org.mockito.Mockito.*;
import com.shopingCardSystem.Model.Cart;
import static org.junit.jupiter.api.Assertions.*;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.junit.jupiter.MockitoExtension;
import com.shopingCardSystem.Repository.CartRepository;


@ExtendWith(MockitoExtension.class)
class CartServiceImplTest {

    @InjectMocks private CartServiceImpl cartService;

    @Mock private CartRepository cartRepository;

    @Test
    public void getAllItems() {

        when(cartRepository.findAll()).thenReturn(Stream.of(new Cart(1, 255, 54, 50), new Cart(2, 30, 20, 20)).collect(Collectors.toList()));
        assertEquals(2, cartService.getAllItems().size());
    }

    @Test
    void getCartgetById() {

        Cart cart = new Cart(3, 222, 40, 15);
        when(cartRepository.findById(3)).thenReturn(cart);
        Cart cartResult = cartService.getCartgetById(3);
        assertEquals(cart, cartResult);
    }

    @Test
    void addCart() {

    Cart cart = new Cart(3, 222, 40, 15);
    when(cartRepository.save(cart)).thenReturn(cart);

    Cart cartResult = cartService.addCart(cart);
    assertEquals(cart, cartResult);
    }

    @Test
    void updateCartById() {
        Cart cart = new Cart(4, 332, 50, 45);
        Mockito.when(cartRepository.save(cart)).thenReturn(null);

        cart.setItemCount(443);
        Mockito.when(cartRepository.save(cart)).thenReturn(cart);
        assertEquals(cart, cartService.updateCartById(cart, cart.getCartId()));
    }

    @Test
    void deleteCardById() {
        Cart cart = new Cart(5, 225, 60, 30);
        cartService.deleteCardById(cart.getCartId());
        verify(cartRepository, times(1)).deleteById(5);
    }
}