package com.shopingCardSystem.Service;

import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.InjectMocks;
import java.util.stream.Stream;
import org.junit.jupiter.api.Test;
import java.util.stream.Collectors;
import static org.mockito.Mockito.*;
import com.shopingCardSystem.Model.Item;
import static org.junit.jupiter.api.Assertions.*;
import org.mockito.junit.jupiter.MockitoExtension;
import org.junit.jupiter.api.extension.ExtendWith;
import com.shopingCardSystem.Repository.ItemReository;


@ExtendWith(MockitoExtension.class)
class ItemServiceImplTest {

    @InjectMocks  private ItemServiceImpl itemService;

    @Mock private  ItemReository itemReository;

    @Test
   public void getAllItems() {

        when(itemReository.findAll()).thenReturn(Stream.of(new Item(1, 5, 333, 500, 20), new Item(2, 3, 343, 1000, 30)).collect(Collectors.toList()));
        assertEquals(2, itemService.getAllItems().size());
    }

    @Test
    void getItemById() {

        Item item = new Item(3, 4, 555, 1000, 40);
        when(itemReository.findById(3)).thenReturn(item);
        Item itemResult = itemService.getItemById(3);
        assertEquals(item, itemResult);

    }

    @Test
    void addItem() {

            Item item1 = new Item(5, 5, 2000, 666, 20);
            when(itemReository.save(item1)).thenReturn(item1);

            Item itemResult = itemService.addItem(item1);
            assertEquals(item1, itemResult);
    }

    @Test
    void updateItemById() {
        Item item2 = new Item(5, 5, 2000, 666, 20);
        Mockito.when(itemReository.save(item2)).thenReturn(null);
        item2.setDiscount(10);
        Mockito.when(itemReository.save(item2)).thenReturn(item2);
        assertEquals(item2, itemService.updateItemById(item2, item2.getItemId()));
    }

    @Test
    void deleteItemById() {
        Item item = new Item(6, 5, 6000, 100, 25);
        itemService.deleteItemById(item.getItemId());
        verify(itemReository, times(1)).deleteById(6);
    }

}